PPG
-------

Main
^^^^^^^^^^^^^^^^
*ppg_process()*
"""""""""""""""
.. autofunction:: neurokit2.ppg.ppg_process

*ppg_analyze()*
"""""""""""""""
.. autofunction:: neurokit2.ppg.ppg_analyze

*ppg_simulate()*
""""""""""""""""
.. autofunction:: neurokit2.ppg.ppg_simulate

*ppg_plot()*
"""""""""""""
.. autofunction:: neurokit2.ppg.ppg_plot


Preprocessing
^^^^^^^^^^^^^^^^
*ppg_clean()*
"""""""""""""
.. autofunction:: neurokit2.ppg.ppg_clean

*ppg_peaks()*
"""""""""""""""""
.. autofunction:: neurokit2.ppg.ppg_peaks


Analysis
^^^^^^^^^
*ppg_eventrelated()*
""""""""""""""""""""
.. autofunction:: neurokit2.ppg.ppg_eventrelated

*ppg_intervalrelated()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.ppg.ppg_intervalrelated


Miscellaneous
^^^^^^^^^^^^^^^^
*ppg_findpeaks()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.ppg.ppg_findpeaks


*Any function appearing below this point is not explicitly part of the documentation and should be added. Please open an issue if there is one.*

.. automodule:: neurokit2.ppg
   :members:
   :exclude-members: ppg_process, ppg_analyze, ppg_simulate, ppg_plot, ppg_clean, ppg_peaks, ppg_findpeaks, ppg_rate, ppg_eventrelated, ppg_intervalrelated
